@@ -10,5 +10,10 @@ $authenticate_text = array (
 'waitwhiletransfer'	=>	'Please wait while you are transferred...',
 'clicknowait'		=>	'Click here if you do not wish to wait.',
 
+
+// Added in 0.9.7
+'accountdisabled'       =>      'Your account is disabled.  Contact a full admin.',
+
+
 );
 ?>
