@@ -36,7 +36,7 @@ $details_text = array (
 'commentby'           =>    'Comment by',
 'addcomment'          =>    'Add comment',
 'fileuploadedby'      =>    'File uploaded by',
-'uploadafile'         =>    'Upload a file to attach',
+'uploadafile'         =>    'Attach a file',             // Changed in version 0.9.8
 'description'         =>    'Description',
 'uploadnow'           =>    'Upload now!',
 'thesearerelated'     =>    'These tasks are related to this task',
@@ -108,25 +108,51 @@ $details_text = array (
 
 // Added in version 0.9.7
 
-'selectareason'       =>   'Select a reason',
-'assigntome'          =>   'Assign to me',
-'reopenrequest'       =>   'Request re-open',
-'requestclose'        =>   'Request closure',
-'ownershiptaken'      =>   'User took ownership',
-'closerequestmade'    =>   'Requested task closure',
-'reopenrequestmade'   =>   'Requested task be re-opened',
-'taskdependson'       =>   'This task depends upon',
-'taskblocks'          =>   'This task blocks these from closing',
-'addnew'              =>   'Add new',
-'depadded'            =>   'Dependency added:',
-'depaddedother'       =>   'This task added as dependency:',
-'depremoved'          =>   'Dependency removed:',
-'depremovedother'     =>   'This task removed from other task\'s dependency list:',
-'showdetailserror'    =>   'That task does not exist, or you don\'t have permission to view it.',
-'makeprivate'         =>   'Make Private',
-'makepublic'          =>   'Make Public',
-'taskmadeprivate'    =>    'Task made private',
-'taskmadepublic'     =>    'Privacy removed - task made public',
+'selectareason'         =>    'Select a reason',
+'assigntome'            =>    'Assign to me',
+'reopenrequest'         =>    'Request re-open',
+'requestclose'          =>    'Request closure',
+'ownershiptaken'        =>    'User took ownership',
+'closerequestmade'      =>    'Requested task closure',
+'reopenrequestmade'     =>    'Requested task be re-opened',
+'taskdependson'         =>    'This task depends upon',
+'taskblocks'            =>    'This task blocks these from closing',
+'addnew'                =>    'Add new',
+'depadded'              =>    'Dependency added:',
+'depaddedother'         =>    'This task added as dependency:',
+'depremoved'            =>    'Dependency removed:',
+'depremovedother'       =>    'This task removed from other task\'s dependency list:',
+'showdetailserror'      =>    'That task does not exist, or you don\'t have permission to view it.',
+'makeprivate'           =>    'Make Private',
+'makepublic'            =>    'Make Public',
+'taskmadeprivate'       =>    'Task made private',
+'taskmadepublic'        =>    'Privacy removed - task made public',
+
+
+// Added in version 0.9.8
+
+'confirmdeletecomment'  =>    'Really delete this comment?  All attachments will also be deleted!',
+'confirmdeleteattach'   =>    'Really delete this attachment?',
+'selectedhistory'       =>    'Showing selected history details',
+'showallhistory'        =>    'Show full history tab again',
+'hidethis'              =>    'Hide this area again',
+'mark100'               =>    'Mark task 100% complete',
+'watchtask'             =>    'Watch this task',
+'stopwatching'          =>    'Stop watching this task',
+'commentlink'           =>    'Link to this comment',
+'submitreq'             =>    'Submit request',
+'givereason'            =>    'Reason for this request',
+'pmreqdenied'           =>    'Project Manager denied request',
+'taskpendingreq'        =>    'Project Manager action pending.  See the History tab for details.',
+'previoustask'          =>    'Previous task',
+'nexttask'              =>    'Next task',
+'duedate'               =>    'Due Date',
+'selectmorefiles'       =>    'Select more files',
+'attachnoperms'         =>    'There are attachments with this comment, but you have no permission to view them.',
+'open'                  =>    'OPEN',
+'closed'                =>    'CLOSED',
+'depgraph'              =>    'View Dependency Graph',
+'reset'                 =>    'Reset',
 
 );
 ?>
