@@ -120,14 +120,14 @@ $modify_text = array (
 'customiseproject'      =>        'Customise this project',
 'projectupdated'        =>        'Project preferences updated',
 'emptytitle'            =>        'You left the Project Title field blank.  Go back and fix it.',
-'loginbelow'            =>        'You may now attempt to login using the form below.',
+'loginbelow'            =>        'You may now attempt to login.',      // Changed in version 0.9.8
 'attachmentdeleted'     =>        'The attachment has been deleted',
 
 // Added in 0.9.6
 
 'reminderadded'         =>        'Your reminder has been added.',
 'reminderdeleted'       =>        'The selected reminder has been deleted.',
-'flyspraytask'		=>        'Flyspray task',
+'flyspraytask'          =>        'Flyspray task',
 'fieldsmissing'         =>        'Some fields contained no or invalid data.',
 'relatedinvalid'        =>        'There is no such task.',
 'relatedproject'        =>        'Task is attached to a different project.',
@@ -159,5 +159,12 @@ $modify_text = array (
 'taskmadepublic'        =>        'This task has been made public again',
 'realandnotify'         =>        'You need to fill in the Real Name field, and either the Email Address or Jabber ID field.',
 
+
+// Added in version 0.9.8
+
+'pmreqdenied'           =>       'Project Manager request denied',
+'massopsuccess'         =>       'Mass operations successful - where permissions allowed',
+'usernotexist'          =>       'That username does not exist on this Flyspray installation',
+'commentattachperms'    =>       'You cannot delete that comment - no permission to delete attachments',
 );
 ?>
