@@ -1,19 +1,24 @@
 <?php
-get_language_pack($lang, 'newgroup');
+$fs->get_language_pack($lang, 'newgroup');
 
 // Make sure that only admins are using this page
-if (($permissions['admin'] == '1' && $_GET['project'] == '0')
-     OR $permissions['manage_project'] == '1') {
+if (@$permissions['is_admin'] == '1'
+     OR ($permissions['manage_project'] == '1' && !empty($_GET['project']) ) ) {
 
-if ($_GET['project'] == '0') {
+if (empty($_GET['project']) )
+{
    $forproject = $newgroup_text['globalgroups'];
-} else {
-   $project_details = $fs->dbFetchArray($fs->dbQuery("SELECT * FROM flyspray_projects WHERE project_id = ?", array($project_id)));
+} else
+{
+   $result = $db->Query("SELECT * FROM {$dbprefix}projects
+                         WHERE project_id = ?",
+                         array($_GET['project']));
+   $project_details = $db->FetchArray($result);
    $forproject = $project_details['project_title'];
-};
+}
 ?>
 
-<form action="index.php?project=<?php echo $_GET['project'];?>" method="post" id="newgroup">
+<form action="<?php echo $conf['general']['baseurl'];?>index.php" method="post" id="newgroup">
 <h1><?php echo $newgroup_text['createnewgroup'] . ' - ' . $forproject;?></h1>
 <p><em><?php echo $newgroup_text['requiredfields'];?></em> <strong>*</strong></p>
 
@@ -22,6 +27,7 @@ if ($_GET['project'] == '0') {
       <td>
       <input type="hidden" name="do" value="modify" />
       <input type="hidden" name="action" value="newgroup" />
+      <input type="hidden" name="project" value="<?php echo $_GET['project'];?>" />
       <label for="groupname">
       <?php echo $newgroup_text['groupname'];?></label></td>
       <td><input id="groupname" type="text" name="group_name" size="20" maxlength="20" /> <strong>*</strong></td>
