@@ -1,29 +1,15 @@
 <?php
-get_language_pack($lang, 'newuser');
+$fs->get_language_pack($lang, 'newuser');
 
 // Make sure that only admins are using this page, unless
 // The application preferences allow anonymous signups
-if ($permissions['is_admin'] == "1"
-    OR ($flyspray_prefs['spam_proof'] != '1' 
+if (@$permissions['is_admin'] == "1"
+    OR ($flyspray_prefs['spam_proof'] != '1'
     && $flyspray_prefs['anon_reg'] == '1'
-    && !$_COOKIE['flyspray_userid'])) {
+    && !isset($_COOKIE['flyspray_userid']) ) ) {
 ?>
 
-<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01//EN" "http://www.w3.org/TR/html4/strict.dtd">
-<head>
-  <title>Flyspray: <?php echo $newuser_text['registernewuser'];?></title>
-  <link href="../themes/<?php echo $flyspray_prefs['theme_style'];?>/theme.css" rel="stylesheet" type="text/css">
-  <script type="text/javascript"> <!--
-    function Disable()
-    {
-    document.form1.buSubmit.disabled = true;
-    document.form1.submit();
-    }
-//-->  </script>
-</head>
-
-<body>
-<form name="form1" action="index.php" method="post" id="registernewuser">
+<form name="form1" action="<?php echo $conf['general']['baseurl'];?>index.php" method="post" id="registernewuser">
 
 <h1><?php echo $newuser_text['registernewuser'];?></h1>
 <p>
@@ -66,14 +52,14 @@ if ($permissions['is_admin'] == "1"
       <input type="radio" name="notify_type" value="2" /><?php echo $newuser_text['jabber'];?> <br />
       </td>
     </tr>
-    <?php if ($permissions['is_admin'] == "1") { ?>
+    <?php if (@$permissions['is_admin'] == "1") { ?>
     <tr>
       <td><label for="groupin"><?php echo $newuser_text['globalgroup'];?></label></td>
       <td>
       <select id="groupin" class="adminlist" name="group_in">
       <?php // Get the group names
-      $get_group_details = $fs->dbQuery("SELECT group_id, group_name FROM flyspray_groups WHERE belongs_to_project = '0' ORDER BY group_id ASC");
-      while ($row = $fs->dbFetchArray($get_group_details)) {
+      $get_group_details = $db->Query("SELECT group_id, group_name FROM {$dbprefix}groups WHERE belongs_to_project = '0' ORDER BY group_id ASC");
+      while ($row = $db->FetchArray($get_group_details)) {
         echo "<option value=\"{$row['group_id']}\">{$row['group_name']}</option>";
       };
       ?>
@@ -85,15 +71,12 @@ if ($permissions['is_admin'] == "1"
     ?>
     <tr>
       <td colspan="2" class="buttons">
-      <input class="adminbutton" type="submit" name="buSubmit" value="<?php echo $newuser_text['registeraccount'];?>" onclick="Disable()" />
+      <input class="adminbutton" type="submit" name="buSubmit" value="<?php echo $newuser_text['registeraccount'];?>" />
       </td>
     </tr>
   </table>
 </form>
 
-</body>
-</html>
-
 <?php
-};
+}
 ?>
