@@ -1,5 +1,5 @@
 <?php
-get_language_pack($lang, 'register');
+$fs->get_language_pack($lang, 'register');
 
 // If the application preferences require the use of
 // confirmation codes, use this script
@@ -8,23 +8,25 @@ if ($flyspray_prefs['spam_proof'] == '1'
     && !$COOKIE['flyspray_userid']) {
 
 // If the user came here from their notification link
-if ($_GET['magic']) {
+if (isset($_GET['magic']))
+{
+   // Check that the magic url is valid
+   $check_magic = $db->Query("SELECT * FROM {$dbprefix}registrations
+                              WHERE magic_url = ?",
+                              array($_GET['magic'])
+                            );
 
-    // Check that the magic url is valid
-    $check_magic = $fs->dbQuery("SELECT * FROM flyspray_registrations
-                                 WHERE magic_url = ?",
-                                 array($_GET['magic'])
-                               );
-
-    if (!$fs->dbCountRows($check_magic)) {
+   if (!$db->CountRows($check_magic))
+   {
       echo "<div class=\"redirectmessage\"><p><em>{$register_text['badmagic']}</em></p></div>";
       echo '<meta http-equiv="refresh" content="2; URL=index.php">';
 
-    } else {
+   } else
+   {
     ?>
 
 <h1><?php echo $register_text['registernewuser'];?></h1>
-<form action="index.php" name="form2" method="post" id="registernewuser">
+<form action="<?php echo $conf['general']['baseurl'];?>index.php" name="form2" method="post" id="registernewuser">
   <table class="admin">
     <tr>
       <td colspan="2">
@@ -52,19 +54,20 @@ if ($_GET['magic']) {
       </td>
     </tr>
   </table>
-   
+
    </form>
 
 
   <?php
   // End of checking that the magic url is valid
   };
-  
+
 // If there was no magic url specified
-} else {
+} else
+{
 ?>
 
-<form name="form1" action="index.php" method="post" id="registernewuser">
+<form action="<?php echo $conf['general']['baseurl'];?>index.php" method="post" id="registernewuser">
 
 <h1><?php echo $register_text['registernewuser'];?></h1>
 
@@ -93,7 +96,7 @@ if ($_GET['magic']) {
     <tr>
       <td><label><?php echo $register_text['notifications'];?></label></td>
       <td>
-      <input type="radio" name="notify_type" value="1" checked /><?php echo $register_text['email'];?> <br>
+      <input type="radio" name="notify_type" value="1" checked="checked" /><?php echo $register_text['email'];?> <br />
       <input type="radio" name="notify_type" value="2" /><?php echo $register_text['jabber'];?>
       </td>
     </tr>
@@ -104,7 +107,7 @@ if ($_GET['magic']) {
     </tr>
     <tr>
       <td colspan="2" class="buttons">
-      <input class="adminbutton" type="submit" name="buSubmit" value="<?php echo $register_text['sendcode'];?>" onclick="Disable1()" />
+      <input class="adminbutton" type="submit" name="buSubmit" value="<?php echo $register_text['sendcode'];?>" />
       </td>
     </tr>
   </table>
@@ -115,9 +118,6 @@ if ($_GET['magic']) {
 };
 ?>
 
-</body>
-</html>
-
 <?php
 // End of checking settings
 };
